@@ -77,9 +77,9 @@ class Compliance:
         """
         badge_url = self.badge_image_url()
         if readme_file_format == ReadmeFormat.RESTRUCTUREDTEXT:
-            return ".. image:: {0}\n   :target: {1}".format(badge_url, "https://fair-software.eu")
+            return f".. image:: {badge_url}\n   :target: https://fair-software.eu"
         if readme_file_format == ReadmeFormat.MARKDOWN:
-            return "[![fair-software.eu]({0})]({1})".format(badge_url, "https://fair-software.eu")
+            return f"[![fair-software.eu]({badge_url})](https://fair-software.eu)"
 
         return None
 
@@ -87,7 +87,7 @@ class Compliance:
         """FAIR software badge image URL"""
         color_string = self.color()
         compliance_string = self.urlencode()
-        return "https://img.shields.io/badge/fair--software.eu-{0}-{1}".format(compliance_string, color_string)
+        return f"https://img.shields.io/badge/fair--software.eu-{compliance_string}-{color_string}"
 
     def color(self) -> str:
         """Traffic light color for badge based on compliance count
