@@ -21,7 +21,7 @@ class CitationMixin:
         if reason == "":
             self._print_state(check_name="skipped (no reason provided)", state=True)
             return True
-        self._print_state(check_name="skipped (reason: {0})".format(reason), state=True)
+        self._print_state(check_name=f"skipped (reason: {reason})", state=True)
         return True
 
     def has_citation_file(self):
