@@ -29,7 +29,7 @@ class RegistryMixin:
                 self._print_state(check_name="skipped (no reason provided)", state=True)
             return True
         if not self.is_quiet:
-            self._print_state(check_name="skipped (reason: {0})".format(reason), state=True)
+            self._print_state(check_name=f"skipped (reason: {reason})", state=True)
         return True
 
     def has_ascl_badge(self):
