@@ -10,4 +10,4 @@ def get_from_github_with_auth_frontend(url, apikeys):
     username = apikeys.get("github-user")
     key = apikeys.get("github-key")
 
-    return requests.get(url, headers, auth=(username, key))
+    return requests.get(url, headers, auth=(username, key), timeout=10)
