@@ -3,4 +3,4 @@ import requests
 
 def get_from_gitlab_no_auth_frontend(url):
     """ """
-    return requests.get(url)
+    return requests.get(url, timeout=10)
