@@ -17,4 +17,4 @@ def get_from_gitlab_with_auth_api(url, apikeys):
     username = apikeys.get("gitlab-user")
     key = apikeys.get("gitlab-key")
 
-    return requests.get(url, headers, auth=(username, key))
+    return requests.get(url, headers, auth=(username, key), timeout=10)
