@@ -1,2 +1,2 @@
 def find_license_gitlab():
-    pass
+    """  """
